==> nextcloud-24.0.11.tgz: nextcloud/apps/dashboard/l10n/sv.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard app",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Påbörja din dag informerad\n\nNextcloud Dashboard är din startpunkt på dagen som ger dig en\növerblick av dina kommande bokningar, brådskande e-post och chattmeddelanden,\ninkommande ärenden, senaste tweets och mycket mer! Användare kan lägga till widgetar\nde gillar och anpassa bakgrunden efter deras tycke.",
    "\"{title} icon\"" : "\"{title}-ikon\"",
    "Customize" : "Anpassa",
    "Edit widgets" : "Ändra widgetar",
    "Get more widgets from the App Store" : "Hämta fler widgetar från Appstore",
    "Weather service" : "Vädertjänst",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "För din integritet skull hämtas väderdata av din Nextcloud-server på dina vägnar så att vädertjänsten inte får någon personlig information.",
    "Weather data from Met.no" : "Väderdata från Met.no",
    "geocoding with Nominatim" : "geokodning med Nominatim",
    "elevation data from OpenTopoData" : "höjddata från OpenTopoData",
    "Weather" : "Väder",
    "Status" : "Status",
    "Good morning" : "God morgon",
    "Good morning, {name}" : "God morgon, {name}",
    "Good afternoon" : "God eftermiddag",
    "Good afternoon, {name}" : "God eftermiddag, {name}",
    "Good evening" : "God kväll",
    "Good evening, {name}" : "God kväll, {name}",
    "Hello" : "Hej",
    "Hello, {name}" : "Hej, {name}",
    "Change background image" : "Byt bakgrundsbild",
    "Pick from Files" : "Välj från filer",
    "Default images" : "Standardbilder",
    "Plain background" : "Enkel bakgrund",
    "Insert from {productName}" : "Infoga från {productName}"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.12.tgz: nextcloud/apps/dashboard/l10n/sv.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard app",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! Users can add the widgets they like and change the background to their liking." : "Börja din dag informerad\n\nNextcloud Dashboard är din startpunkt på dagen som ger dig en överblick över dina kommande bokningar, brådskande e-post, chattmeddelanden, inkommande ärenden, senaste tweets och mycket mer! Användare kan lägga till widgetar de gillar och anpassa bakgrunden efter deras tycke.",
    "\"{title} icon\"" : "\"{title}-ikon\"",
    "Customize" : "Anpassa",
    "Edit widgets" : "Ändra widgetar",
    "Get more widgets from the App Store" : "Hämta fler widgetar från Appstore",
    "Weather service" : "Vädertjänst",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "För din integritet skull hämtas väderdata av din Nextcloud-server på dina vägnar så att vädertjänsten inte får någon personlig information.",
    "Weather data from Met.no" : "Väderdata från Met.no",
    "geocoding with Nominatim" : "geokodning med Nominatim",
    "elevation data from OpenTopoData" : "höjddata från OpenTopoData",
    "Weather" : "Väder",
    "Status" : "Status",
    "Good morning" : "God morgon",
    "Good morning, {name}" : "God morgon, {name}",
    "Good afternoon" : "God eftermiddag",
    "Good afternoon, {name}" : "God eftermiddag, {name}",
    "Good evening" : "God kväll",
    "Good evening, {name}" : "God kväll, {name}",
    "Hello" : "Hej",
    "Hello, {name}" : "Hej, {name}",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Påbörja din dag informerad\n\nNextcloud Dashboard är din startpunkt på dagen som ger dig en\növerblick av dina kommande bokningar, brådskande e-post och chattmeddelanden,\ninkommande ärenden, senaste tweets och mycket mer! Användare kan lägga till widgetar\nde gillar och anpassa bakgrunden efter deras tycke.",
    "Change background image" : "Byt bakgrundsbild",
    "Pick from Files" : "Välj från filer",
    "Default images" : "Standardbilder",
    "Plain background" : "Enkel bakgrund",
    "Insert from {productName}" : "Infoga från {productName}"
},
"nplurals=2; plural=(n != 1);");
